==> haskell-postgresql-binary-0.12.1-33-i686.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1
id: postgresql-binary-0.12.1-3A3PoXsKXyfLnIpxcIAw5F
key: postgresql-binary-0.12.1-3A3PoXsKXyfLnIpxcIAw5F
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
abi: 21eca36c8aa07e22da77cfe9fde06712
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/postgresql-binary-0.12.1
hs-libraries: HSpostgresql-binary-0.12.1-3A3PoXsKXyfLnIpxcIAw5F
depends:
    binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn
    bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF time-1.8.0.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    network-ip-0.3.0.2-FgCIMadcpT25twK322rzp
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    containers-0.5.10.2 loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
    placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK transformers-0.5.2.0
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn=30c53a1b44a8bee666fa61ef03f6f505
             bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5=271b4423b9b417c7c13243b94e5d3b3c
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF=c8e798cbad0965162f320ece9cbec567
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             network-ip-0.3.0.2-FgCIMadcpT25twK322rzp=1e711ba337aac4be623a87c070976ade
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM=8db9befb4805c019cfc12dd1a7cbf51c
             placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK=b5084dceea7cb14fc6171868377b607e
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.1-34-i686.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1
id: postgresql-binary-0.12.1-Al1OlceKtldAq53TRbGGyZ
key: postgresql-binary-0.12.1-Al1OlceKtldAq53TRbGGyZ
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
abi: 083b87972f1fbc2163cc3feee35de286
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/postgresql-binary-0.12.1
hs-libraries: HSpostgresql-binary-0.12.1-Al1OlceKtldAq53TRbGGyZ
depends:
    binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn
    bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF time-1.8.0.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    network-ip-0.3.0.2-FgCIMadcpT25twK322rzp
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    containers-0.5.10.2 loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
    placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK transformers-0.5.2.0
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn=30c53a1b44a8bee666fa61ef03f6f505
             bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5=271b4423b9b417c7c13243b94e5d3b3c
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF=c8e798cbad0965162f320ece9cbec567
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             network-ip-0.3.0.2-FgCIMadcpT25twK322rzp=1e711ba337aac4be623a87c070976ade
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM=8db9befb4805c019cfc12dd1a7cbf51c
             placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK=b5084dceea7cb14fc6171868377b607e
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
